function [ c ] = bottleneck_twoElements(p, q)
% Bottleneck_twoElements compute the c^*(p,q) = \min \{ ||p-q||_\infty,
% 0.5\max\{|py - px|, |qy - qx| \} \}. Measures the cost of matching p with q
% against the cost of matching both points with the diagonal.
%
% Author: Weiyu Huang, whuang@seas.upenn.edu
% version 1
% 2017 Feb 17
% 
% References: W. Huang and A. Ribeiro, Persistent Homology Lower Bounds on
% High Order Network Distances, IEEE Transaction on Signal Processing, vol.
% 65, no. 2, pp. 319-334, January 2017.
%
% W. Huang and A. Ribeiro, Metrics in the Space of High Order Networks,
% IEEE Transaction on Signal Processing, vol. 64, no. 3, pp. 615-629,
% February 2016.

% INPUT: p,q both in 2d: px, py, qx, qy  

% ||p-q||_\infty
c1 = norm(p-q, Inf);

% 0.5\max\{|py - px|, |qy - qx| \}
c2 = 0.5 * max(abs(p(1) - p(2)), abs(q(1) - q(2)));

% c
c = min(c1, c2); 

end

