% Script to generate MDS plots to compare coauthorship networks in the
% paper Persistent Homology Lower Bounds on Network Distances
%
% Author: Weiyu Huang, whuang@seas.upenn.edu
% version 1
% 2017 Feb 17
% 
% References: W. Huang and A. Ribeiro, Persistent Homology Lower Bounds on
% High Order Network Distances, IEEE Transaction on Signal Processing, vol.
% 65, no. 2, pp. 319-334, January 2017.
%
% W. Huang and A. Ribeiro, Metrics in the Space of High Order Networks,
% IEEE Transaction on Signal Processing, vol. 64, no. 3, pp. 615-629,
% February 2016.

%% create persistence intervals

% This part needs to call DataScript in the folder Active_Data with
% variable FILENAME indicating the filename of the excel to be opened and
% analyzed.
%
% Since it needs to be called manually for each excel file, we attach the
% stored persistence for 5Y_persistence_intervals.mat (5 year data for 11
% journals in math and engieering) and ASW_persistence_intervals.mat (IEEE
% TAC, TSP, and TWC)
%
% The readers interested in generating persistent intervals themselves can
% download the separate file coauthorship_data on weiyuhuang.net

%% compute pairwise distance between networks
 
% Order of persistence diagram to exam, can be either 0 or 1 or 2
%
order = 2;

% The threshold to remove homological features that are very short. A large
% value improves computational speed but may deteriorate performance; a
% small value improves accuracy at the cost of longer computation
%
thres = 6.1; 

% Whether keep homological features that end in infinity. If so, make then
% ending in 1. If not, all infinity features are removed. 
% 
inf_kept = 1;

A = construct_interval_structure( 1, order );
distance_R2 = distance_matrix_bottleneck( A, thres, inf_kept );

%% visulization via MDS 5Y

D = distance_R2;
D = D + 1e-15 * rand(length(D)); D = (D + D') / 2; D = D - diag(diag(D));

Y = mdscale(D, 2);

sig = ['or'; 'or'; 'or'; 'or'; 'or'; 'or'; 'or'; 'or'; 'or'; 'or'; ...          % math
       'db'; 'db'; 'db'; 'db'; 'db'; 'db'; 'db'; 'db'; 'db'; 'db'; 'db'; 'db']; % engineering
sig_switch = 1:22;

figure;
set(gca,'FontSize',14)
hold on; grid on;

for i = 1:length(Y)
    scatter( Y(i, 1), Y(i, 2), 90, sig( sig_switch(i),:), 'filled', 'LineWidth', 1.9);
end

xlength = get(gca, 'xlim'); xlength = xlength(2) - xlength(1);

% Add labels for TSP
%
text(Y(19, 1) - 0.013 * xlength, Y(19, 2), 'TSP \rightarrow', 'FontSize', 14, 'HorizontalAlignment', 'right');
text(Y(20, 1) - 0.013 * xlength, Y(20, 2), 'TSP \rightarrow', 'FontSize', 14, 'HorizontalAlignment', 'right');

%% visulization via MDS ASW

compare_id = 3;   % 0 - everything. 1 - TAC vs TSP. 2 - TAC vs TWC. 3 - TSP vs TWC.

subset = subset_ASW(compare_id);
D = DD(subset, subset);
D = D + 1e-14 * rand(length(D)); D = (D + D') / 2; D = D - diag(diag(D));

Y = mdscale(D, 2);

sig = ['or'; 'or'; 'or'; 'or'; 'or'; 'or'; 'or'; 'or'; 'or'; 'or'; ... % TAC
       'db'; 'db'; 'db'; 'db'; 'db'; 'db'; 'db'; 'db'; 'db'; 'db'; ... % TSP
       'sk'; 'sk'; 'sk'; 'sk'; 'sk'; 'sk'; 'sk'; 'sk'; 'sk'; 'sk'];    % TWC
sig_switch = 1:length(Y);

figure;
set(gca,'FontSize',14)
hold on; grid on;
sig_now = sig(subset, :);

for i = 1:length(Y)
    scatter( Y(i, 1), Y(i, 2), 90, sig_now(sig_switch(i),:), 'filled', 'LineWidth', 1.9);
end

set(gcf, 'position', [1000, 800, 560, 392])
